==> flutter_firebase_basic_tools-0.0.20.tar.gz: lib/widgets/courses_carousel.dart <==
import 'dart:async';
import 'package:flutter_firebase_basic_tools/widgets/courses_carousel_item.dart';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter/material.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

class CoursesCarousel extends StatefulWidget {
  @override
  _CoursesCarouselState createState() => _CoursesCarouselState();
}

class _CoursesCarouselState extends State<CoursesCarousel> {
  int currentOffset = 0;
  double currentPage = 1;
  PageController pageController = PageController(
    initialPage: 1,
    viewportFraction: 0.3,
  );
  int totalPages = 4;
  bool activeAutoScroll = true;

  autoScroll() {
    Timer(Duration(seconds: 13), () {
      if (currentPage < totalPages - 2) {
        pageController.nextPage(
            duration: Duration(milliseconds: 900), curve: Curves.linear);
      } else {
        pageController.animateToPage(1,
            duration: Duration(milliseconds: 900), curve: Curves.linear);
      }

      if (activeAutoScroll) {
        autoScroll();
      }
    });
  }

  @override
  void initState() {
    super.initState();
    autoScroll();
  }

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).orientation == Orientation.portrait;

    PageController newPageController = PageController(
      initialPage: pageController.initialPage,
      viewportFraction: isPortrait ? 0.7 : 0.3,
    );

    pageController = newPageController;

    return Container(
      child: Column(
        children: <Widget>[
          Spacer(flex: 2),
          Expanded(
            flex: 8,
            child: Container(
              child: PageView(
                scrollDirection: Axis.horizontal,
                onPageChanged: (int page) {
                  setState(() {
                    currentPage = page.toDouble();
                  });
                },
                //physics: BouncingScrollPhysics(),
                controller: pageController,
                children: <Widget>[
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                ],
              ),
            ),
          ),
          Spacer(flex: 2),
          SmoothPageIndicator(
            controller: pageController,
            count: totalPages,
            effect: WormEffect(
              dotColor: CustomColors().green,
              activeDotColor: CustomColors().lightAqua,
              spacing: 20,
              dotHeight: 13,
              dotWidth: 13,
            ),
          ),
        ],
      ),
    );
  }
}

==> flutter_firebase_basic_tools-0.0.140.tar.gz: lib/widgets/courses_carousel.dart <==
import 'dart:async';
import 'package:flutter_firebase_basic_tools/widgets/courses_carousel_item.dart';

import 'package:flutter/material.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

class CoursesCarousel extends StatefulWidget {
  @override
  _CoursesCarouselState createState() => _CoursesCarouselState();
}

class _CoursesCarouselState extends State<CoursesCarousel> {
  int currentOffset = 0;
  double currentPage = 1;
  PageController pageController = PageController(
    initialPage: 1,
    viewportFraction: 0.3,
  );
  int totalPages = 4;
  bool activeAutoScroll = true;

  autoScroll() {
    Timer(Duration(seconds: 13), () {
      if (currentPage < totalPages - 2) {
        pageController.nextPage(
            duration: Duration(milliseconds: 900), curve: Curves.linear);
      } else {
        pageController.animateToPage(1,
            duration: Duration(milliseconds: 900), curve: Curves.linear);
      }

      if (activeAutoScroll) {
        autoScroll();
      }
    });
  }

  @override
  void initState() {
    super.initState();
    autoScroll();
  }

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).orientation == Orientation.portrait;

    PageController newPageController = PageController(
      initialPage: pageController.initialPage,
      viewportFraction: isPortrait ? 0.7 : 0.3,
    );

    pageController = newPageController;

    return Container(
      child: Column(
        children: <Widget>[
          Spacer(flex: 2),
          Expanded(
            flex: 8,
            child: Container(
              child: PageView(
                scrollDirection: Axis.horizontal,
                onPageChanged: (int page) {
                  setState(() {
                    currentPage = page.toDouble();
                  });
                },
                //physics: BouncingScrollPhysics(),
                controller: pageController,
                children: <Widget>[
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                  CoursesCarouselItem(
                    imageUrl: 'assets/images/project_demo_1.jpg',
                    title: "News",
                    subtitle: "",
                    text: "",
                  ),
                ],
              ),
            ),
          ),
          Spacer(flex: 2),
          SmoothPageIndicator(
            controller: pageController,
            count: totalPages,
            effect: WormEffect(
              dotColor: Colors.blueGrey,
              activeDotColor: Colors.blueGrey,
              spacing: 20,
              dotHeight: 13,
              dotWidth: 13,
            ),
          ),
        ],
      ),
    );
  }
}
